@@ -1,10 +1,10 @@
-from execelasticsearch.mapping import MappingData
+from execelasticsearch.mapping import MappingMethod
 from execelasticsearch.connection import ClientConfig
 from execelasticsearch.handler import ExecES
 
 
 __all__ = [
-    'MappingData',
+    'MappingMethod',
     'ClientConfig',
     'ExecES'
 ]
